==> react-native-hotqa-sdk-0.2.1.tgz: package/src/pages/home/styles.js <==
import {StyleSheet} from 'react-native';

export const styles = StyleSheet.create({
  safe: {
    flex: 1,
    backgroundColor: '#fff',
  },
  content: {
    flex: 1,
    backgroundColor: '#fff',
    alignItems: 'center',
  },

  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },

  viewShadow: {
    alignItems: 'center',
    justifyContent: 'center',
    width: 160,
    height: 160,
    borderRadius: 80,
    backgroundColor: '#fff',
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 2,
    },
    shadowOpacity: 0.23,
    shadowRadius: 2.62,
    elevation: 4,
  },
  viewRadius: {
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#fff6e9',
    width: 150,
    height: 150,
    borderRadius: 75,
    borderWidth: 1,
    borderStyle: 'dashed',
    borderColor: '#f9ce76',
  },
  body: {
    alignItems: 'center',
  },
  title: {
    marginVertical: '5%',
    fontSize: 20,
    marginHorizontal: 20,
    fontWeight: 'bold',
    textAlign: 'center',
  },
  outline: {
    paddingHorizontal: 16,
    textAlign: 'center',
    fontSize: 14,
  },
  name: {
    fontSize: 18,
    color: '#3b4056',
    fontWeight: 'bold',
  },
  hintName: {
    fontSize: 16,
    color: 'gray',
    fontWeight: 'bold',
  },
  viewUser: {
    marginTop: 20,
    height: 55,
    width: 330,
    borderWidth: 1,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    paddingLeft: 15,
    borderRadius: 15,
    borderColor: '#bfbfbf',
  },
  flexView: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  subHeader: {
    marginHorizontal: 5,
    fontSize: 16,
    fontWeight: '500',
    color: '#fff',
    textAlign: 'center',
  },
  logo: {
    width: '30%',
    marginRight: 20,
    height: 60,
  },
  quizView: {
    marginTop: 20,
    borderRadius: 15,
    width: 330,
    height: 55,
    backgroundColor: '#8993bb',
    paddingHorizontal: 20,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  viewTime: {
    backgroundColor: '#fff',
    width: 180,
    height: 45,
    borderRadius: 15,
    justifyContent: 'center',
    padding: 10,
  },
  time: {
    fontSize: 16,
    fontWeight: '500',
    color: '#8993bb',
    textAlign: 'center',
  },
  button: {
    marginVertical: 30,
    backgroundColor: '#2196f3',
    width: 130,
    height: 50,
    borderRadius: 25,
    justifyContent: 'center',
    alignItems: 'center',
  },
  textButton: {
    color: '#fff',
    fontSize: 18,
    fontWeight: 'bold',
  },
  btnBack: {
    backgroundColor: '#DDD',
    width: 46,
    height: 46,
    borderRadius: 23,
    justifyContent: 'center',
    alignItems: 'center',
    marginLeft: 20,
  },
  iconBack: {
    fontSize: 30,
    color: '#FFF',
  },
});

==> react-native-hotqa-sdk-0.2.7.tgz: package/src/pages/home/styles.js <==
import {StyleSheet} from 'react-native';

export const styles = StyleSheet.create({
  safe: {
    flex: 1,
    backgroundColor: '#fff',
  },
  content: {
    flex: 1,
    backgroundColor: '#fff',
    alignItems: 'center',
    justifyContent: 'center',
  },

  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center',
  },

  viewShadow: {
    alignItems: 'center',
    justifyContent: 'center',
    width: 160,
    height: 160,
    borderRadius: 80,
    backgroundColor: '#fff',
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 2,
    },
    shadowOpacity: 0.23,
    shadowRadius: 2.62,
    elevation: 4,
  },
  viewRadius: {
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#fff6e9',
    width: 150,
    height: 150,
    borderRadius: 75,
    borderWidth: 1,
    borderStyle: 'dashed',
    borderColor: '#f9ce76',
  },
  body: {
    alignItems: 'center',
  },
  title: {
    fontSize: 40,
    color: '#4C51D9',
    marginHorizontal: 20,
    fontWeight: '800',
    textAlign: 'center',
  },
  outline: {
    paddingHorizontal: 16,
    textAlign: 'center',
    fontSize: 14,
  },
  name: {
    fontSize: 18,
    color: '#3b4056',
    fontWeight: 'bold',
  },
  hintName: {
    fontSize: 16,
    color: 'gray',
    fontWeight: 'bold',
  },
  viewUser: {
    marginTop: 20,
    height: 55,
    width: 330,
    borderWidth: 1,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    paddingLeft: 15,
    borderRadius: 15,
    borderColor: '#bfbfbf',
  },
  flexView: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    top: 40,
    left: 0,
    right: 0,
    position: 'absolute',
  },
  logo: {
    width: '30%',
    marginRight: 20,
    height: 60,
  },
  quizView: {
    marginVertical: 40,
    borderRadius: 15,
    width: '50%',
    borderColor: '#4C51D9',
    borderWidth: 1,
    paddingHorizontal: 16,
    paddingVertical: 30,
    flexDirection: 'row',
    alignItems: 'center',
  },
  viewInfo: {
    flex: 0.5,
    justifyContent: 'center',
    alignItems: 'center',
  },
  time: {
    fontSize: 20,
    color: '#4D4D4D',
    textAlign: 'center',
    marginTop: 6,
  },
  button: {
    marginTop: 20,
    backgroundColor: '#FFC107',
    width: '50%',
    paddingVertical: 12,
    borderRadius: 20,
    justifyContent: 'center',
    alignItems: 'center',
  },
  textSize30: {
    color: '#fff',
    fontSize: 28,
  },
  btnBack: {
    backgroundColor: '#DDD',
    width: 46,
    height: 46,
    borderRadius: 23,
    justifyContent: 'center',
    alignItems: 'center',
    marginLeft: 20,
  },
  iconBack: {
    fontSize: 30,
    color: '#FFF',
  },
  btnTutorial: {
    width: 50,
    height: 50,
    borderRadius: 25,
    backgroundColor: '#DBEBFF',
    padding: 5,
    marginRight: 20,
    alignItems: 'center',
    justifyContent: 'center',
  },
  iconTutorial: {
    width: 25,
    height: 28,
  },

  iconClock: {
    width: 35,
    height: 35,
  },

  iconQuestion: {
    width: 38,
    height: 38,
  },
});
